Keg-Storage
###########

.. image:: https://circleci.com/gh/level12/keg-storage.svg?style=svg
  :target: https://circleci.com/gh/level12/keg-storage

.. image:: https://codecov.io/github/level12/keg-storage/coverage.svg?branch=master
  :target: https://codecov.io/github/level12/keg-storage?branch=master

.. _Keg: https://pypi.python.org/pypi/Keg


A simple storage interface with multiple back ends for use in a Keg_ app.


Usage
=====
